@@ -2,6 +2,7 @@
 
 # System
 from typing import Dict, List, Optional
+import traceback, html
 
 # Pip
 from jsoncodable import JSONCodable
@@ -28,14 +29,14 @@ class Post(JSONCodable):
         comments_json: Optional[List[Dict]] = None
     ):
         self.sub            = post_json['subreddit']
-        self.title          = post_json['title']
-        self.content        = post_json['selftext']
+        self.title          = html.unescape(post_json['title'])
+        self.content        = html.unescape(post_json['selftext'])
         self.nsfw           = post_json['over_18']
         self.pinned         = post_json['pinned']
         self.id             = post_json['id']
         self.score          = post_json['score']
         self.upvote_ratio   = post_json['upvote_ratio']
-        self.flair_text     = post_json['link_flair_text']
+        self.flair_text     = html.unescape(post_json['link_flair_text'])
         self.url            = post_json['url'].strip('/')
         self.ts             = int(post_json['created_utc'])
         self.author         = post_json['author']
@@ -48,13 +49,13 @@ class Post(JSONCodable):
         self.video = None
         self.image = None
 
-        if post_json['is_video']:
-            video = Video(post_json)
+        video = Video(post_json)
 
-            if video.video_url is not None:
-                self.video = video
-                self.type = PostType.Video
+        if video.video_url is not None:
+            self.video = video
+            self.type = PostType.Video
         else:
+            self.video = None
             image = Image(post_json['preview'])
 
             if image.url is not None:
@@ -69,8 +70,8 @@ class Post(JSONCodable):
         for comment_json in comments_json:
             try:
                 self.comments.append(Comment(comment_json['data']))
-            except Exception as e:
-                print('comment_e', e)
+            except:
+                traceback.print_exc()
 
                 pass
 
